#[non_exhaustive]pub struct AuditEvent {
pub id: String,
pub event_data: String,
pub event_data_checksum: Option<String>,
}Expand description
An event from a source outside of Amazon Web Services that you want CloudTrail to log.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe original event ID from the source event.
event_data: StringThe content of an audit event that comes from the event, such as userIdentity, userAgent, and eventSource.
event_data_checksum: Option<String>A checksum is a base64-SHA256 algorithm that helps you verify that CloudTrail receives the event that matches with the checksum. Calculate the checksum by running a command like the following:
printf %s $eventdata | openssl dgst -binary -sha256 | base64
Implementations
Sourceimpl AuditEvent
impl AuditEvent
Sourcepub fn event_data(&self) -> &str
pub fn event_data(&self) -> &str
The content of an audit event that comes from the event, such as userIdentity, userAgent, and eventSource.
Sourcepub fn event_data_checksum(&self) -> Option<&str>
pub fn event_data_checksum(&self) -> Option<&str>
A checksum is a base64-SHA256 algorithm that helps you verify that CloudTrail receives the event that matches with the checksum. Calculate the checksum by running a command like the following:
printf %s $eventdata | openssl dgst -binary -sha256 | base64
Sourceimpl AuditEvent
impl AuditEvent
Sourcepub fn builder() -> AuditEventBuilder
pub fn builder() -> AuditEventBuilder
Creates a new builder-style object to manufacture AuditEvent.