#[non_exhaustive]pub struct ResultErrorEntry {
pub id: String,
pub error_code: String,
pub error_message: String,
}Expand description
Includes the error code and error message for events that could not be ingested by CloudTrail.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe original event ID from the source event that could not be ingested by CloudTrail.
error_code: StringThe error code for events that could not be ingested by CloudTrail. Possible error codes include: FieldTooLong, FieldNotFound, InvalidChecksum, InvalidData, InvalidRecipient, InvalidEventSource, AccountNotSubscribed, Throttling, and InternalFailure.
error_message: StringThe message that describes the error for events that could not be ingested by CloudTrail.
Implementations
Sourceimpl ResultErrorEntry
impl ResultErrorEntry
Sourcepub fn id(&self) -> &str
pub fn id(&self) -> &str
The original event ID from the source event that could not be ingested by CloudTrail.
Sourcepub fn error_code(&self) -> &str
pub fn error_code(&self) -> &str
The error code for events that could not be ingested by CloudTrail. Possible error codes include: FieldTooLong, FieldNotFound, InvalidChecksum, InvalidData, InvalidRecipient, InvalidEventSource, AccountNotSubscribed, Throttling, and InternalFailure.
Sourcepub fn error_message(&self) -> &str
pub fn error_message(&self) -> &str
The message that describes the error for events that could not be ingested by CloudTrail.
Sourceimpl ResultErrorEntry
impl ResultErrorEntry
Sourcepub fn builder() -> ResultErrorEntryBuilder
pub fn builder() -> ResultErrorEntryBuilder
Creates a new builder-style object to manufacture ResultErrorEntry.